==> kubernetes-model-networking-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/HTTPIngressPathFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class HTTPIngressPathFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent<A>{
  public HTTPIngressPathFluentImpl() {
  }
  public HTTPIngressPathFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath instance) {
    this.withBackend(instance.getBackend()); 
    this.withPath(instance.getPath()); 
    this.withPathType(instance.getPathType()); 
  }
  private io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder backend;
  private java.lang.String path;
  private java.lang.String pathType;
  
  /**
   * This method has been deprecated, please use method buildBackend instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend getBackend() {
    return this.backend!=null?this.backend.build():null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend buildBackend() {
    return this.backend!=null?this.backend.build():null;
  }
  public A withBackend(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend backend) {
    _visitables.get("backend").remove(this.backend);
    if (backend!=null){ this.backend= new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
  }
  public java.lang.Boolean hasBackend() {
    return this.backend != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> withNewBackend() {
    return new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluentImpl.BackendNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
    return new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluentImpl.BackendNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> editBackend() {
    return withNewBackendLike(getBackend());
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> editOrNewBackend() {
    return withNewBackendLike(getBackend() != null ? getBackend(): new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
    return withNewBackendLike(getBackend() != null ? getBackend(): item);
  }
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  public java.lang.String getPathType() {
    return this.pathType;
  }
  public A withPathType(java.lang.String pathType) {
    this.pathType=pathType; return (A) this;
  }
  public java.lang.Boolean hasPathType() {
    return this.pathType != null;
  }
  
  /**
   * Method is deprecated. use withPathType instead.
   */
  @java.lang.Deprecated
  public A withNewPathType(java.lang.String arg0) {
    return (A)withPathType(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPIngressPathFluentImpl that = (HTTPIngressPathFluentImpl) o;
    if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (pathType != null ? !pathType.equals(that.pathType) :that.pathType != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backend,  path,  pathType,  super.hashCode());
  }
  public class BackendNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    BackendNestedImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(this, item);
    }
    BackendNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder builder;
    public N and() {
      return (N) HTTPIngressPathFluentImpl.this.withBackend(builder.build());
    }
    public N endBackend() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-networking-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/HTTPIngressPathFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class HTTPIngressPathFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent<A>{
  public HTTPIngressPathFluentImpl() {
  }
  public HTTPIngressPathFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPath instance) {
    this.withBackend(instance.getBackend()); 
    this.withPath(instance.getPath()); 
    this.withPathType(instance.getPathType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder backend;
  private java.lang.String path;
  private java.lang.String pathType;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildBackend instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend getBackend() {
    return this.backend!=null?this.backend.build():null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend buildBackend() {
    return this.backend!=null?this.backend.build():null;
  }
  public A withBackend(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend backend) {
    _visitables.get("backend").remove(this.backend);
    if (backend!=null){ this.backend= new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
  }
  public java.lang.Boolean hasBackend() {
    return this.backend != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> withNewBackend() {
    return new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluentImpl.BackendNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
    return new io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluentImpl.BackendNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> editBackend() {
    return withNewBackendLike(getBackend());
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> editOrNewBackend() {
    return withNewBackendLike(getBackend() != null ? getBackend(): new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
    return withNewBackendLike(getBackend() != null ? getBackend(): item);
  }
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * Method is deprecated. use withPath instead.
   */
  @java.lang.Deprecated
  public A withNewPath(java.lang.String arg0) {
    return (A)withPath(new String(arg0));
  }
  public java.lang.String getPathType() {
    return this.pathType;
  }
  public A withPathType(java.lang.String pathType) {
    this.pathType=pathType; return (A) this;
  }
  public java.lang.Boolean hasPathType() {
    return this.pathType != null;
  }
  
  /**
   * Method is deprecated. use withPathType instead.
   */
  @java.lang.Deprecated
  public A withNewPathType(java.lang.String arg0) {
    return (A)withPathType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPIngressPathFluentImpl that = (HTTPIngressPathFluentImpl) o;
    if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (pathType != null ? !pathType.equals(that.pathType) :that.pathType != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backend,  path,  pathType,  additionalProperties,  super.hashCode());
  }
  public class BackendNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1beta1.HTTPIngressPathFluent.BackendNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    BackendNestedImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackend item) {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(this, item);
    }
    BackendNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBackendBuilder builder;
    public N and() {
      return (N) HTTPIngressPathFluentImpl.this.withBackend(builder.build());
    }
    public N endBackend() {
      return and();
    }
    
  }
  
}
